==> RSTouchscreenNG-0.92.2.zip: RSTouchscreenNG/projects/pages/src/lib/index.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';

import { HttpClientModule } from '@angular/common/http';
import { RouterModule } from '@angular/router';

import {RepetierServer, VisualAids} from 'binding';
import {FrontUIModule, RSUIVisualAids} from 'front-ui';
import {PrinterListComponent} from "./printers.component";
import {DashboardComponent} from "./dashboard.component";
import {PrintStatusComponent} from "./printstatus.component";
import {
    MoveComponent,
    MoveZComponent,
    MoveEComponent, MoveZBabystepComponent
} from "./move.component";
import {NetworksComponent} from "./networks.component";
import {GCodesComponent, GCodeInfoComponent} from "./gcodes.component";
import {PrintQueueComponent} from "./printqueue.component";
import {ServerCommandsComponent} from "./server-commands.component";
import {PrinterCommandsComponent} from "./printer-commands.component";
import {WebcamComponent} from "./webcam.component";
import {ParamsComponent} from "./params.component";
import {ImportComponent} from "./import.component";
import {WLANComponent} from "./wlan.component";
import {TemperaturesComponent} from "./temperatures.component";
import {LanguagesComponent} from "./languages.component";
import {MessagesComponent} from "./messages.component";
import {ChangeFilamentComponent} from "./changefilament.component";
import {ConsoleComponent} from "./console.component";
import {ScreensaverComponent} from "./screensaver.component";
import {UnlockScreenComponent} from "./unlock.component";
import {SettingsComponent} from "./settings.component";
import {InfoComponent} from "./info.component";
import {EepromComponent} from "./eeprom.component";
import {TimesettingsComponent} from "./timesettings.component";
import {RecoverComponent} from "./recover.component";

@NgModule({
    declarations: [
        DashboardComponent,
        PrinterListComponent,
        PrintStatusComponent,
        MoveComponent,
        MoveZComponent,
        MoveEComponent,
        MoveZBabystepComponent,
        NetworksComponent,
        GCodesComponent,
        PrintQueueComponent,
        ServerCommandsComponent,
        PrinterCommandsComponent,
        WebcamComponent,
        ParamsComponent,
        ImportComponent,
        WLANComponent,
        TemperaturesComponent,
        LanguagesComponent,
        MessagesComponent,
        ChangeFilamentComponent,
        ConsoleComponent,
        GCodeInfoComponent,
        ScreensaverComponent,
        UnlockScreenComponent,
        SettingsComponent,
        InfoComponent,
        EepromComponent,
        TimesettingsComponent,
        RecoverComponent
    ],
    imports: [
        CommonModule,
        HttpClientModule,
        RouterModule,
        FrontUIModule
    ],
    providers: [
        RepetierServer,
        { provide: VisualAids, useClass: RSUIVisualAids }
    ],
    bootstrap: []
})
export class PagesModule { }

==> RSTouchscreenNG-0.94.2.zip: RSTouchscreenNG/projects/pages/src/lib/index.ts <==
/* (C) 2016-2020 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {CommonModule} from "@angular/common";
import {NgModule} from "@angular/core";

import {HttpClientModule} from "@angular/common/http";
import {RouterModule} from "@angular/router";

import {RepetierServer, VisualAids} from "binding";
import {FrontUIModule, RSUIVisualAids} from "front-ui";
import {PrinterListComponent} from "./printers.component";
import {DashboardComponent} from "./dashboard.component";
import {PrintStatusComponent} from "./printstatus.component";
import {
  MoveComponent,
  MoveZComponent,
  MoveEComponent, MoveZBabystepComponent
} from "./move.component";
import {NetworksComponent} from "./networks.component";
import {GCodesComponent, GCodeInfoComponent} from "./gcodes.component";
import {PrintQueueComponent} from "./printqueue.component";
import {ServerCommandsComponent} from "./server-commands.component";
import {PrinterCommandsComponent} from "./printer-commands.component";
import {WebcamComponent} from "./webcam.component";
import {ParamsComponent} from "./params.component";
import {ImportComponent} from "./import.component";
import {WLANComponent} from "./wlan.component";
import {TemperaturesComponent} from "./temperatures.component";
import {LanguagesComponent} from "./languages.component";
import {MessagesComponent} from "./messages.component";
import {ChangeFilamentComponent} from "./changefilament.component";
import {ConsoleComponent} from "./console.component";
import {ScreensaverComponent} from "./screensaver.component";
import {UnlockScreenComponent} from "./unlock.component";
import {SettingsComponent} from "./settings.component";
import {InfoComponent} from "./info.component";
import {EepromComponent} from "./eeprom.component";
import {TimesettingsComponent} from "./timesettings.component";
import {RecoverComponent} from "./recover.component";
import {WebActionsComponent} from "./web-actions.component";
import {HardwareInfoComponent} from "./hardware-info.component";

@NgModule({
  declarations: [
    DashboardComponent,
    PrinterListComponent,
    PrintStatusComponent,
    MoveComponent,
    MoveZComponent,
    MoveEComponent,
    MoveZBabystepComponent,
    NetworksComponent,
    GCodesComponent,
    PrintQueueComponent,
    ServerCommandsComponent,
    PrinterCommandsComponent,
    WebcamComponent,
    ParamsComponent,
    ImportComponent,
    WLANComponent,
    TemperaturesComponent,
    LanguagesComponent,
    MessagesComponent,
    ChangeFilamentComponent,
    ConsoleComponent,
    GCodeInfoComponent,
    ScreensaverComponent,
    UnlockScreenComponent,
    SettingsComponent,
    InfoComponent,
    EepromComponent,
    TimesettingsComponent,
    RecoverComponent,
    WebActionsComponent,
    HardwareInfoComponent
  ],
  imports: [
    CommonModule,
    HttpClientModule,
    RouterModule,
    FrontUIModule
  ],
  providers: [
    RepetierServer,
    {provide: VisualAids, useClass: RSUIVisualAids}
  ],
  bootstrap: []
})
export class PagesModule {
}
